/*----------------------------------------------------------------------------*-

   main.h (Release 2018-06-07a)

  --------------------------------------------------------------------------------------
   
   This is the Processor Header file.

   This file needs to be adapted for each project.

-*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*-

  This code is copyright (c) 2014-2018 SafeTTy Systems Ltd.

  This code forms part of a Time-Triggered Reference Design (TTRD) that is 
  documented in the following book: 

   Pont, M.J. (2016) 
   "The Engineering of Reliable Embedded Systems (Second Edition)", 
   Published by SafeTTy Systems Ltd. ISBN: 978-0-9930355-3-1.

  Both the TTRDs and the above book ("ERES2") describe patented 
  technology and are subject to copyright and other restrictions.

  This code may be used without charge: [i] by universities and colleges on 
  courses for which a degree up to and including 'MSc' level (or equivalent) 
  is awarded; [ii] for non-commercial projects carried out by individuals 
  and hobbyists.

  Any and all other use of this code and / or the patented technology 
  described in ERES2 requires purchase of a ReliabiliTTy Technology Licence:
  http://www.safetty.net/technology/reliabilitty-technology-licences

  Please contact SafeTTy Systems Ltd if you require clarification of these 
  licensing arrangements: http://www.safetty.net/contact

  CorrelaTTor, DecomposiTTor, DuplicaTTor, MoniTTor, PredicTTor, ReliabiliTTy,  
  SafeTTy, SafeTTy Systems, TriplicaTTor and WarranTTor are registered 
  trademarks or trademarks of SafeTTy Systems Ltd in the UK & other countries.

-*----------------------------------------------------------------------------*/

#ifndef _MAIN_H
#define _MAIN_H 1

// HSI library
#include "..\hsi_library\stm32f4xx_rcc.h"

// Required system operating frequency (in Hz)
// Will be checked in the scheduler initialisation file
#define REQUIRED_PROCESSOR_CORE_CLOCK (168000000)

// Port header
#include "..\port\port.h"

// Processor module
#include "..\processor\ttrd2-08d-t0405a-v001a_processor.h"

// Scheduler module
#include "..\scheduler\ttrd2-08d-t0405a-v001a_scheduler.h"


/*----------------------------------------------------------------------------*-
   Processor constants
-*----------------------------------------------------------------------------*/

// Generic constants
#define TRUE                  (0x12345678U)
#define FALSE                 (0xEDCBA987U)

// Used for task return values
#define RETURN_NORMAL_STATE   (0x5555AAAAU)
#define RETURN_ABNORMAL_STATE (0xAAAA5555U)

// Used to report results of data-integrity checks on Duplicated Variables
#define DATA_OK               (0x12AB34CDU)
#define DATA_CORRUPTED        (0xED54CB32U)

// Used in checks of stored register configuration
#define REGISTERS_OK          (0x5A5A5A5AU)
#define REGISTERS_CHANGED     (0xA5A5A5A5U)

// Used to indicate if iWDT is running
#define WDT_RUNNING           (0xAAAAAAAAU)
#define WDT_NOT_RUNNING       (0x55555555U)
#define WDT_UNKNOWN_STATE     (0x55AA55AAU)

#endif

/*----------------------------------------------------------------------------*-
  ------------------------------ END OF FILE ---------------------------------
-*----------------------------------------------------------------------------*/

