/*----------------------------------------------------------------------------*-

  ttrd2-08d-t0405a-v001a_heartbeat_amber_task.c (Release 2018-06-07a)

  ----------------------------------------------------------------------------
   
  Simple 'Heartbeat' task.  Controls amber (orange) user LED.

  Targets DuplicaTTor Evaluation Board (STM32F405, v002).

  Code can be loaded onto either MCU.

  Usually released once per second => flashes 0.5 Hz, 50% duty cycle.

-*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*-

  This code is copyright (c) 2014-2018 SafeTTy Systems Ltd.

  This code forms part of a Time-Triggered Reference Design (TTRD) that is 
  documented in the following book: 

   Pont, M.J. (2016) 
   "The Engineering of Reliable Embedded Systems (Second Edition)", 
   Published by SafeTTy Systems Ltd. ISBN: 978-0-9930355-3-1.

  Both the TTRDs and the above book ("ERES2") describe patented 
  technology and are subject to copyright and other restrictions.

  This code may be used without charge: [i] by universities and colleges on 
  courses for which a degree up to and including 'MSc' level (or equivalent) 
  is awarded; [ii] for non-commercial projects carried out by individuals 
  and hobbyists.

  Any and all other use of this code and / or the patented technology 
  described in ERES2 requires purchase of a ReliabiliTTy Technology Licence:
  http://www.safetty.net/technology/reliabilitty-technology-licences

  Please contact SafeTTy Systems Ltd if you require clarification of these 
  licensing arrangements: http://www.safetty.net/contact

  CorrelaTTor, DecomposiTTor, DuplicaTTor, MoniTTor, PredicTTor, ReliabiliTTy,  
  SafeTTy, SafeTTy Systems, TriplicaTTor and WarranTTor are registered 
  trademarks or trademarks of SafeTTy Systems Ltd in the UK & other countries.

-*----------------------------------------------------------------------------*/

// Module header
#include "ttrd2-08d-t0405a-v001a_heartbeat_amber_task.h"

/*----------------------------------------------------------------------------*-

  HEARTBEAT_AMBER_Init()

  Prepare for HEARTBEAT_AMBER_Update() function - see below.
  
  PARAMETERS:
     None.

  LONG-TERM DATA:
     None.

  MCU HARDWARE:
     GPIO pin (Heartbeat pin - Amber LED).

  PRE-CONDITION CHECKS:
     None.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     None.

  RETURN VALUE:
     None.

-*----------------------------------------------------------------------------*/
void HEARTBEAT_AMBER_Init(void)
   {
   GPIO_InitTypeDef GPIO_InitStruct;
     
   // Enable peripheral clock 
   RCC_AHB1PeriphClockCmd(AMBER_LED_CLOCK, ENABLE);
     
   // Configure port pin for the LED
   GPIO_InitStruct.GPIO_Mode  = GPIO_Mode_OUT;
   GPIO_InitStruct.GPIO_OType = GPIO_OType_PP;
   GPIO_InitStruct.GPIO_Speed = GPIO_High_Speed; 
   GPIO_InitStruct.GPIO_PuPd  = GPIO_PuPd_NOPULL;
   GPIO_InitStruct.GPIO_Pin   = AMBER_LED_PIN;
   
   GPIO_Init(AMBER_LED_PORT, &GPIO_InitStruct); 
   }

/*----------------------------------------------------------------------------*-

  HEARTBEAT_AMBER_Deinit()

  Deinit function for heartbeat pin.

  Here we set the pin to 'input' mode.
  
  PARAMETERS:
     None.

  LONG-TERM DATA:
     None.

  MCU HARDWARE:
     GPIO pin (Heartbeat pin - Amber LED).

  PRE-CONDITION CHECKS:
     None.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     None.

  RETURN VALUE:
     None.

-*----------------------------------------------------------------------------*/
void HEARTBEAT_AMBER_Deinit(void)
   {
   // To perform the deinit action, we configure the pin for INPUT

   GPIO_InitTypeDef GPIO_InitStruct;
     
   // Enable peripheral clock 
   RCC_AHB1PeriphClockCmd(AMBER_LED_CLOCK, ENABLE);
     
   // Configure port pin for the LED
   GPIO_InitStruct.GPIO_Mode  = GPIO_Mode_IN;
   GPIO_InitStruct.GPIO_Speed = GPIO_High_Speed; 
   GPIO_InitStruct.GPIO_PuPd  = GPIO_PuPd_NOPULL;
   GPIO_InitStruct.GPIO_Pin   = AMBER_LED_PIN;
   
   GPIO_Init(AMBER_LED_PORT, &GPIO_InitStruct); 
   }

/*----------------------------------------------------------------------------*-

  HEARTBEAT_AMBER_Update()

  Flashes at 0.5 Hz.

  Must schedule every second (soft deadline).
   
  PARAMETERS:
     None.

  LONG-TERM DATA:
     Heartbeat_state_s (W)

  MCU HARDWARE:
     GPIO pin (Heartbeat pin - Amber LED).

  PRE-CONDITION CHECKS:
     None.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     None.

  WCET:
     Not yet determined.

  BCET:
     Not yet determined.

  RETURN VALUE:
     None.
 
-*----------------------------------------------------------------------------*/
void HEARTBEAT_AMBER_Update(void)
   {
   static uint32_t Heartbeat_state_s = 0;

   // Change the LED from OFF to ON (or vice versa)
   if (Heartbeat_state_s == 1)
      {
      Heartbeat_state_s = 0;
      GPIO_ResetBits(AMBER_LED_PORT, AMBER_LED_PIN);
      }
   else
      {
      Heartbeat_state_s = 1;
      GPIO_SetBits(AMBER_LED_PORT, AMBER_LED_PIN);
      }
   }

/*----------------------------------------------------------------------------*-
  ------------------------------ END OF FILE ---------------------------------
-*----------------------------------------------------------------------------*/
