/*----------------------------------------------------------------------------*-

  ttrd2-08d-t0405a-v001a_processor_task.c (Release 2018-06-07a)

  ----------------------------------------------------------------------------
   
  Processor Task.
  
  For DuplicaTTor Evaluation Board (DEB-0405).

  Supports reset-based Mode changes requested by user (by pressing BTN).
  
  Also supports periodic (planned) Mode changes, every 10 seconds.

  Please refer to 'ERES2' (Chapter 8) for further information.

-*----------------------------------------------------------------------------*/
/*----------------------------------------------------------------------------*-

  This code is copyright (c) 2014-2018 SafeTTy Systems Ltd.

  This code forms part of a Time-Triggered Reference Design (TTRD) that is 
  documented in the following book: 

   Pont, M.J. (2016) 
   "The Engineering of Reliable Embedded Systems (Second Edition)", 
   Published by SafeTTy Systems Ltd. ISBN: 978-0-9930355-3-1.

  Both the TTRDs and the above book ("ERES2") describe patented 
  technology and are subject to copyright and other restrictions.

  This code may be used without charge: [i] by universities and colleges on 
  courses for which a degree up to and including 'MSc' level (or equivalent) 
  is awarded; [ii] for non-commercial projects carried out by individuals 
  and hobbyists.

  Any and all other use of this code and / or the patented technology 
  described in ERES2 requires purchase of a ReliabiliTTy Technology Licence:
  http://www.safetty.net/technology/reliabilitty-technology-licences

  Please contact SafeTTy Systems Ltd if you require clarification of these 
  licensing arrangements: http://www.safetty.net/contact

   CorrelaTTor, DuplicaTTor, MoniTTor, PredicTTor, ReliabiliTTy, SafeTTy, 
   SafeTTy Systems and WarranTTor are registered trademarks or trademarks 
   of SafeTTy Systems Ltd in the UK and other countries.

-*----------------------------------------------------------------------------*/

#include "..\main\main.h"

// Reads switch state
#include "..\tasks\ttrd2-08d-t0405a-v001a_switch_task.h"

/*----------------------------------------------------------------------------*-

  PROCESSOR_TASK_Init()

  Prepare for Processor Task - see below.
  
  PARAMETERS:
     None.

  LONG-TERM DATA:
     None.

  MCU HARDWARE:
     None.

  PRE-CONDITION CHECKS:
     None.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     None.

  RETURN VALUE:
     None.

-*----------------------------------------------------------------------------*/
void PROCESSOR_TASK_Init(void)
   {
   // Do nothing
   }

/*----------------------------------------------------------------------------*-

  PROCESSOR_TASK_Deinit()

  Deinit function for Processor Task.
  
  PARAMETERS:
     None.

  LONG-TERM DATA:
     None.

  MCU HARDWARE:
     None.

  PRE-CONDITION CHECKS:
     None.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     None.

  RETURN VALUE:
     None.

-*----------------------------------------------------------------------------*/
void PROCESSOR_TASK_Deinit(void)
   {
   // Nothing to do here
   }

/*----------------------------------------------------------------------------*-

  PROCESSOR_TASK_Update()

  Periodic task that controls mode transitions.

  This version is employed in all "normal" modes.

  Call every second in this demo.
   
  PARAMETERS:
     None.

  LONG-TERM DATA:
     Seconds_count_s (W)

  MCU HARDWARE:
     None.

  PRE-CONDITION CHECKS:
     Data-integrity check on Seconds_count_s.

  POST-CONDITION CHECKS:
     None.

  ERROR DETECTION / ERROR HANDLING:
     Only PreCs.

  WCET:
     Not yet determined.

  BCET:
     Not yet determined.

  RETURN VALUE:
     RETURN_NORMAL_STATE or RETURN_ABNORMAL_STATE.
 
-*----------------------------------------------------------------------------*/
void PROCESSOR_TASK_Update(void)
   {
   static uint32_t Seconds_count_s = 0;

   uint32_t Change_mode = 0;
   eProc_MoSt New_mode;

   // Read the switch state
   if (SWITCH_BTN_Get_State() == BTN_PRESSED)
      {
      // Switch pressed - change mode immediately
      Seconds_count_s = 0;
      Change_mode = 1;
      }

   // ... otherwise change mode every 10 seconds
   if (Seconds_count_s++ == 10)
      {
      Seconds_count_s = 0;
      Change_mode = 1;
      }

   // Handle mode changes
   if (Change_mode == 1)
      {
      switch (PROCESSOR_Get_MoSt())
         {
         default:
            {
            // Should not be here ...
            PROCESSOR_Perform_Safe_Shutdown();
            break;
            }

         case NORMAL_01_M:
            {
            New_mode = NORMAL_02_M;
            break;
            }

         case NORMAL_02_M:
            {
            New_mode = NORMAL_03_M;
            break;
            }

         case NORMAL_03_M:
            {
            New_mode = NORMAL_01_M;
            break;
            }
         }

      // Change mode (no fault)
      PROCESSOR_Set_MoSt(New_mode);
      PROCESSOR_Change_MoSt();   
      }
   }

/*----------------------------------------------------------------------------*-
  ------------------------------ END OF FILE ---------------------------------
-*----------------------------------------------------------------------------*/
